;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "tsc" "20251222.1802"
  "Core Tree-sitter APIs."
  '((emacs "27.1"))
  :url "https://github.com/emacs-tree-sitter/elisp-tree-sitter"
  :commit "d12aff8ee91dcd643da0a65a3bcee7be9a3cac68"
  :revdesc "d12aff8ee91d"
  :keywords '("languages" "tools" "parsers" "dynamic-modules" "tree-sitter")
  :authors '(("Tuấn-Anh Nguyễn" . "ubolonton@gmail.com")
             ("Jorge Javier Araya Navarro" . "jorgejavieran@yahoo.com.mx"))
  :maintainers '(("Jen-Chieh Shen" . "jcs090218@gmail.com")))
